@@ -1,3 +1,4 @@
+import os
 import sys
 import asyncio
 
@@ -10,8 +11,8 @@ import pandas as pd
 
 
 class GSDBS:
-    def __init__(self):
-        self.version = "0.1.17"
+    def __init__(self, creadPath):
+        self.version = "0.1.23"
         self.credentials = None
         self.accessToken = None
         self.dtablename = None
@@ -19,6 +20,7 @@ class GSDBS:
         self.sriBuildInfo = list()
         self.data = pd.DataFrame()
         self.statement = None
+        self.creadPath = creadPath
         self.readCredentials()
         self.getToken()
         self.CGSResponseCode = {}
@@ -32,7 +34,7 @@ class GSDBS:
     def readCredentials(self):
         try:
             print(f'GS-DBMS Python client version: {self.version}')
-            f = open("gscred.yml", "r")
+            f = open(self.creadPath + "/gscred.yml", "r")
             cred = f.read()
             f.close()
             self.credentials = yaml.safe_load(cred)['cred']
@@ -43,20 +45,24 @@ class GSDBS:
                     or ('password' not in self.credentials.keys())
                     or ('client_id' not in self.credentials.keys())
                     or ('client_secret' not in self.credentials.keys())):
-                print('Error in credentials')
+                raise ValueError('error: credentials')
                 return
         except Exception as e:
-            print('Missing Credentials')
             print(e)
         return
 
     def getToken(self):
-        data = {'grant_type': 'password', 'username': self.credentials['user'],
-                'password': self.credentials['password']}
-        access_token_response = requests.post(self.credentials['oauthurl'], data=data, verify=True,
-                                              allow_redirects=False,
-                                              auth=(self.credentials['client_id'], self.credentials['client_secret']))
-        self.accessToken = json.loads(access_token_response.text)
+        try:
+            data = {'grant_type': 'password', 'username': self.credentials['user'],
+                    'password': self.credentials['password']}
+            access_token_response = requests.post(self.credentials['oauthurl'], data=data, verify=True,
+                                                  allow_redirects=False,
+                                                  auth=(self.credentials['client_id'], self.credentials['client_secret']))
+            self.accessToken = json.loads(access_token_response.text)
+            if 'error' in self.accessToken:
+                raise ValueError('error:' + self.accessToken['error'])
+        except Exception as e:
+            print(e)
         return
 
     def setupCGSResponseCodes(self):
